##  Applying Filter
The Interface Circle Map Report allows users to filter data based on specific criteria, such as Business Capability, Technology Component, Application, etc. This can help users create customized views of Interfaces and components. To apply a filter you can use both the filter bar on top or Filter facets on the left-hand side which becomes visible when you move the mouse pointer to the left side of the window.
For example, you can just focus on the Applications and their interfaces being used in one business area, here in the example below Human Resources.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274ec8237a44101495babaafedf85e12_LowRes.png)
